
provider = {'project_slug': 'best_eva', 'providers': ['aws'], 'aws_regions': ['us-east-2', 'us-wast-1'], 'do_stuff': '/home/rob/PycharmProjects/terrace/nukikata/tests/test-operator-dicts/checkbox\n', 'demo_loop': [True, True], '_template': '.'}

provider = ['aws']